@@ -64,7 +64,7 @@ labeled_image_new (const char *text,
 	GdkPixbuf *pixbuf = NULL;
 	
 	if (icon_name) {
-		float sizes[] = { 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0,
+		const float sizes[] = { 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0,
 					1.1, 1.2, 1.3, 1.4, 1.5, 1.6, 1.7, 1.8, 1.9, 2.0 };
 		pixbuf = test_pixbuf_new_named (icon_name, sizes[random () % G_N_ELEMENTS (sizes)]);
 	}
@@ -82,7 +82,6 @@ image_table_child_enter_callback (GtkWidget *image_table,
 			       GtkWidget *item,
 			       gpointer callback_data)
 {
-#if 0
 	char *text;
 
 	g_return_if_fail (EEL_IS_IMAGE_TABLE (image_table));
@@ -90,8 +89,7 @@ image_table_child_enter_callback (GtkWidget *image_table,
 
 	text = eel_labeled_image_get_text (EEL_LABELED_IMAGE (item));
 
-	g_print ("%s(%s)\n", G_STRFUNC, text);
-#endif
+//	g_print ("%s(%s)\n", G_GNUC_FUNCTION, text);
 }
 
 static void
@@ -99,7 +97,6 @@ image_table_child_leave_callback (GtkWidget *image_table,
 			       GtkWidget *item,
 			       gpointer callback_data)
 {
-#if 0
 	char *text;
 
 	g_return_if_fail (EEL_IS_IMAGE_TABLE (image_table));
@@ -107,8 +104,7 @@ image_table_child_leave_callback (GtkWidget *image_table,
 
 	text = eel_labeled_image_get_text (EEL_LABELED_IMAGE (item));
 
-	g_print ("%s(%s)\n", G_STRFUNC, text);
-#endif
+//	g_print ("%s(%s)\n", G_GNUC_FUNCTION, text);
 }
 
 static void
@@ -123,7 +119,7 @@ image_table_child_pressed_callback (GtkWidget *image_table,
 
 	text = eel_labeled_image_get_text (EEL_LABELED_IMAGE (item));
 
-	g_print ("%s(%s)\n", G_STRFUNC, text);
+	g_print ("%s(%s)\n", G_GNUC_FUNCTION, text);
 }
 
 static void
@@ -138,7 +134,7 @@ image_table_child_released_callback (GtkWidget *image_table,
 
 	text = eel_labeled_image_get_text (EEL_LABELED_IMAGE (item));
 
-	g_print ("%s(%s)\n", G_STRFUNC, text);
+	g_print ("%s(%s)\n", G_GNUC_FUNCTION, text);
 }
 
 static void
@@ -153,7 +149,7 @@ image_table_child_clicked_callback (GtkWidget *image_table,
 
 	text = eel_labeled_image_get_text (EEL_LABELED_IMAGE (item));
 
-	g_print ("%s(%s)\n", G_STRFUNC, text);
+	g_print ("%s(%s)\n", G_GNUC_FUNCTION, text);
 }
 
 static int
@@ -164,7 +160,7 @@ foo_timeout (gpointer callback_data)
 
 	recursion_count++;
 
-	g_print ("%s(%d)\n", G_STRFUNC, recursion_count);
+	g_print ("%s(%d)\n", G_GNUC_FUNCTION, recursion_count);
 	gtk_widget_queue_resize (GTK_WIDGET (callback_data));
 
 	recursion_count--;
@@ -187,12 +183,12 @@ image_table_size_allocate (GtkWidget *image_table,
 
 	if (0) g_timeout_add (0, foo_timeout, callback_data);
 
-	/*gtk_widget_queue_resize (GTK_WIDGET (callback_data));*/
+	//gtk_widget_queue_resize (GTK_WIDGET (callback_data));
 
 	if (0) gtk_widget_size_allocate (GTK_WIDGET (image_table),
 					 &GTK_WIDGET (image_table)->allocation);
 	
-	g_print ("%s(%d)\n", G_STRFUNC, recursion_count);
+	g_print ("%s(%d)\n", G_GNUC_FUNCTION, recursion_count);
 
 	recursion_count--;
 }
